@@ -1,9 +1,8 @@
-from typing import Dict, Any
-
+ 
 class QueryGenerator:
-    
+
     @staticmethod
-    def generate(schema_name: str, table_name: str, data: Dict[str, Any] = None) -> str:
+    def generate(schema_name: str, table_name: str, data: dict[str, str] = None) -> str:
         query = f"EXEC {schema_name}.{table_name}"
  
         if data is not None:
